@@ -19,22 +19,25 @@
 """
 Base task.
 """
-from abc import ABC
-
-from liminal.runners.airflow.model import dag_mutator
+from abc import ABC, abstractmethod
 
 
-class Task(dag_mutator.DagMutator, ABC):
+class Task(ABC):
     """
     Task.
     """
 
     def __init__(self, task_id, dag, parent, trigger_rule, liminal_config, pipeline_config,
-                 task_config):
-        super().__init__(liminal_config)
+                 task_config, executor=None):
+        self.liminal_config = liminal_config
         self.dag = dag
         self.pipeline_config = pipeline_config
         self.task_id = task_id
         self.parent = parent
         self.trigger_rule = trigger_rule
         self.task_config = task_config
+        self.executor = executor
+
+    @abstractmethod
+    def apply_task_to_dag(self, **kwargs):
+        pass
