@@ -25,9 +25,9 @@ class SparkTask(task.Task):
     """
 
     def __init__(self, task_id, dag, parent, trigger_rule, liminal_config, pipeline_config,
-                 task_config):
+                 task_config, executor):
         super().__init__(task_id, dag, parent, trigger_rule, liminal_config, pipeline_config,
-                         task_config)
+                         task_config, executor)
 
     def apply_task_to_dag(self):
         pass
